#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger
version:              1.52.1
visibility:           public
id:                   hledger-1.52.1-6ZnyCkei0Z1G2RAM7sayfI
key:                  hledger-1.52.1-6ZnyCkei0Z1G2RAM7sayfI
license:              GPL-3.0-or-later
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             Command-line interface for the hledger accounting system
description:
    The command-line interface for the hledger accounting system.
    Its basic function is to read a plain text file describing
    financial transactions and produce useful reports.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting. Read more at:
    <https://hledger.org>

category:             Finance, Console
abi:                  ce74bb1f01fa0e935e442822b5fb0ad6
exposed:              True
exposed-modules:
    Hledger.Cli Hledger.Cli.Anchor Hledger.Cli.Anon
    Hledger.Cli.CliOptions Hledger.Cli.Commands
    Hledger.Cli.Commands.Accounts Hledger.Cli.Commands.Activity
    Hledger.Cli.Commands.Add Hledger.Cli.Commands.Aregister
    Hledger.Cli.Commands.Balance Hledger.Cli.Commands.Balancesheet
    Hledger.Cli.Commands.Balancesheetequity
    Hledger.Cli.Commands.Cashflow Hledger.Cli.Commands.Check
    Hledger.Cli.Commands.Close Hledger.Cli.Commands.Codes
    Hledger.Cli.Commands.Commodities Hledger.Cli.Commands.Demo
    Hledger.Cli.Commands.Descriptions Hledger.Cli.Commands.Diff
    Hledger.Cli.Commands.Files Hledger.Cli.Commands.Help
    Hledger.Cli.Commands.Import Hledger.Cli.Commands.Incomestatement
    Hledger.Cli.Commands.Notes Hledger.Cli.Commands.Payees
    Hledger.Cli.Commands.Prices Hledger.Cli.Commands.Print
    Hledger.Cli.Commands.Register Hledger.Cli.Commands.Rewrite
    Hledger.Cli.Commands.Roi Hledger.Cli.Commands.Run
    Hledger.Cli.Commands.Setup Hledger.Cli.Commands.Stats
    Hledger.Cli.Commands.Tags Hledger.Cli.CompoundBalanceCommand
    Hledger.Cli.Conf Hledger.Cli.DocFiles Hledger.Cli.Script
    Hledger.Cli.Utils Hledger.Cli.Version

hidden-modules:       Paths_hledger
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hledger-1.52.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hledger-1.52.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hledger-1.52.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger
hs-libraries:         HShledger-1.52.1-6ZnyCkei0Z1G2RAM7sayfI
depends:
    Decimal-0.5.2-70mhZ6GZ0TgJHvRt9uF1V8
    Diff-0.5-DbK2KXQffeb9yfLb5gceUe
    aeson-2.2.2.0-E8GnKqfyoqV8B1evVkUtMu
    ansi-terminal-1.1-7dL9hv2pnhf1UozNlva3HX base-4.18.2.1
    bytestring-0.11.5.3 cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    directory-1.3.8.5 extra-1.7.16-zRgcudgyh3HVd3DrMjSx2
    filepath-1.4.300.1 githash-0.1.6.3-xOIk0R3aDCH0Z3blr3x0w
    hashable-1.4.7.0-IVKAR4D6WU9H8t6zzGQ76p haskeline-0.8.2.1
    hledger-lib-1.52.1-CS5ppVshv781sY3Z60Ku3E
    http-client-0.7.19-7npayQWK93786YkcsXS9Bz
    http-types-0.12.4-DdbAmHNhx8C4vBT5NO2sZU
    lucid-2.11.20250303-FFkCIQt4eMfBEb1tPihmqk
    math-functions-0.3.4.4-5Jt2FGa69sBGpaf60whTky
    megaparsec-9.7.0-LcQIYWb87vKBQkwIt8CBXH
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    modern-uri-0.3.6.1-5pbYvoVTrlN3e9TZ0SHENy mtl-2.3.1
    process-1.6.19.0 regex-tdfa-1.3.2.5-6tX5Z8DRWKX4ukPh2wCajT
    req-3.13.4-5fMLBktM4YS7I0pS4sAv77
    safe-0.3.21-DSAQtZwVdTj2yqUwStKQoj
    shakespeare-2.1.7.1-9AxaMQorlHV5oT8JIG11W6
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8
    tabular-0.2.2.8-Ly9fepE9sHFB2l1Bgv9bkV
    tasty-1.5.2-FiRZ1IWcSZ79yf7Nf1HVSK
    temporary-1.3-9Sgzyj9UgJk68u87dA2OiK text-2.0.2
    text-ansi-0.3.0.1-849FYvdFVscBIe0xwGSQuR time-1.12.2
    timeit-2.0-DwmItJuhuSm6aktMh1S1ZM transformers-0.6.1.0
    unordered-containers-0.2.20.1-FX7g4DMKoiaDV91wUmRzTu
    utf8-string-1.0.2-BHoErC4pt0C33Qzw2Pf1X1
    utility-ht-0.0.17.2-E8MEOlpSZasPrhtCf4BMW
    wizards-1.0.3-EMndOhiYuHdGTEqrX5mo0v

haddock-interfaces:   /usr/share/doc/hledger/html/hledger.haddock
haddock-html:         /usr/share/doc/hledger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

